==> zio-aws-lightsail_2.12-7.28.29.1-sources.jar: zio/aws/lightsail/model/GetRelationalDatabaseMetricDataResponse.scala <==
package zio.aws.lightsail.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetRelationalDatabaseMetricDataResponse(
    metricName: Optional[zio.aws.lightsail.model.RelationalDatabaseMetricName] =
      Optional.Absent,
    metricData: Optional[Iterable[zio.aws.lightsail.model.MetricDatapoint]] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.GetRelationalDatabaseMetricDataResponse = {
    import GetRelationalDatabaseMetricDataResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.GetRelationalDatabaseMetricDataResponse
      .builder()
      .optionallyWith(metricName.map(value => value.unwrap))(_.metricName)
      .optionallyWith(
        metricData.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.metricData)
      .build()
  }
  def asReadOnly
      : zio.aws.lightsail.model.GetRelationalDatabaseMetricDataResponse.ReadOnly =
    zio.aws.lightsail.model.GetRelationalDatabaseMetricDataResponse
      .wrap(buildAwsValue())
}
object GetRelationalDatabaseMetricDataResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.GetRelationalDatabaseMetricDataResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.lightsail.model.GetRelationalDatabaseMetricDataResponse =
      zio.aws.lightsail.model.GetRelationalDatabaseMetricDataResponse(
        metricName.map(value => value),
        metricData.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def metricName
        : Optional[zio.aws.lightsail.model.RelationalDatabaseMetricName]
    def metricData
        : Optional[List[zio.aws.lightsail.model.MetricDatapoint.ReadOnly]]
    def getMetricName: ZIO[
      Any,
      AwsError,
      zio.aws.lightsail.model.RelationalDatabaseMetricName
    ] = AwsError.unwrapOptionField("metricName", metricName)
    def getMetricData: ZIO[Any, AwsError, List[
      zio.aws.lightsail.model.MetricDatapoint.ReadOnly
    ]] = AwsError.unwrapOptionField("metricData", metricData)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.GetRelationalDatabaseMetricDataResponse
  ) extends zio.aws.lightsail.model.GetRelationalDatabaseMetricDataResponse.ReadOnly {
    override val metricName
        : Optional[zio.aws.lightsail.model.RelationalDatabaseMetricName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.metricName())
        .map(value =>
          zio.aws.lightsail.model.RelationalDatabaseMetricName.wrap(value)
        )
    override val metricData
        : Optional[List[zio.aws.lightsail.model.MetricDatapoint.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.metricData())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.lightsail.model.MetricDatapoint.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.GetRelationalDatabaseMetricDataResponse
  ): zio.aws.lightsail.model.GetRelationalDatabaseMetricDataResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-lightsail_2.13-5.17.104.4-sources.jar: zio/aws/lightsail/model/GetRelationalDatabaseMetricDataResponse.scala <==
package zio.aws.lightsail.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetRelationalDatabaseMetricDataResponse(
    metricName: Option[zio.aws.lightsail.model.RelationalDatabaseMetricName] =
      None,
    metricData: Option[Iterable[zio.aws.lightsail.model.MetricDatapoint]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.GetRelationalDatabaseMetricDataResponse = {
    import GetRelationalDatabaseMetricDataResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.GetRelationalDatabaseMetricDataResponse
      .builder()
      .optionallyWith(metricName.map(value => value.unwrap))(_.metricName)
      .optionallyWith(
        metricData.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.metricData)
      .build()
  }
  def asReadOnly
      : zio.aws.lightsail.model.GetRelationalDatabaseMetricDataResponse.ReadOnly =
    zio.aws.lightsail.model.GetRelationalDatabaseMetricDataResponse
      .wrap(buildAwsValue())
}
object GetRelationalDatabaseMetricDataResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.GetRelationalDatabaseMetricDataResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.lightsail.model.GetRelationalDatabaseMetricDataResponse =
      zio.aws.lightsail.model.GetRelationalDatabaseMetricDataResponse(
        metricName.map(value => value),
        metricData.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def metricName: Option[zio.aws.lightsail.model.RelationalDatabaseMetricName]
    def metricData
        : Option[List[zio.aws.lightsail.model.MetricDatapoint.ReadOnly]]
    def getMetricName: ZIO[
      Any,
      AwsError,
      zio.aws.lightsail.model.RelationalDatabaseMetricName
    ] = AwsError.unwrapOptionField("metricName", metricName)
    def getMetricData: ZIO[Any, AwsError, List[
      zio.aws.lightsail.model.MetricDatapoint.ReadOnly
    ]] = AwsError.unwrapOptionField("metricData", metricData)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.GetRelationalDatabaseMetricDataResponse
  ) extends zio.aws.lightsail.model.GetRelationalDatabaseMetricDataResponse.ReadOnly {
    override val metricName
        : Option[zio.aws.lightsail.model.RelationalDatabaseMetricName] = scala
      .Option(impl.metricName())
      .map(value =>
        zio.aws.lightsail.model.RelationalDatabaseMetricName.wrap(value)
      )
    override val metricData
        : Option[List[zio.aws.lightsail.model.MetricDatapoint.ReadOnly]] = scala
      .Option(impl.metricData())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.lightsail.model.MetricDatapoint.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.GetRelationalDatabaseMetricDataResponse
  ): zio.aws.lightsail.model.GetRelationalDatabaseMetricDataResponse.ReadOnly =
    new Wrapper(impl)
}
